@font-face {
    font-family: "RobotoLight";
    src: url("font/Roboto-Light.ttf");
}

@font-face {
    font-family: "RobotoRegular";
    src: url("font/Roboto-Regular.ttf");
}

@font-face {
    font-family: "RobotoBold";
    src: url("font/Roboto-Bold.ttf");
}

@font-face {
    font-family: "RobotoBlack";
    src: url("font/Roboto-Black.ttf");
}

@font-face {
    font-family: "RobotoLightItalic";
    src: url("font/Roboto-LightItalic.ttf");
}

body {
    background: #fafafa;
    font-family: Helvetica, Arial, sans-serif;
    font-weight: 400;
    margin-top: 30px;
}

hr {
    margin-top: 25px;
    margin-left: 0;
    text-align: left;
    width: 480px;
}

#content {
    margin: 0 auto;
    width: 480px;
    text-align: justify;
    text-justify: inter-word;
    max-width:100%;
}

#description {
    font-family: 'RobotoLight';
    color: #333;
    width: 480px;
    font-size: 18px;
    text-align: justify;
    text-justify: inter-word;
    max-width:100%;
}

#description p {
    white-space: pre-wrap;
}

#speaker {
    font-family: "RobotoLight";
    font-size: 20px;
    margin: 0;
    max-width:100%;
}

#title {
    font-family: "RobotoBold";
    margin-top: 10px;
    font-size: 30px;
    text-align: left;
    text-justify: none;
    max-width:100%;
}

#views {
    padding-top: 15px;
    font-family: "RobotoBlack";
    font-size: 30px;
}

#speaker_img {
    width: 125px;
    height: auto;
    display: inline-block;
}

#speaker_info {
    display: inline-block;
    margin-left: 10px;
    padding-bottom: 20px;
}

#speaker_info_box {
    font-family: "RobotoBold";    
}

#speaker_box_img {
    margin-top: 20px
}

#speaker_info_profession {
    font-family: "RobotoLightItalic";       
}

#speaker_desc {
    width: 480px;
    margin: 0;
    font-family: "RobotoLight";
}

#date {
    text-align: right;
    width: 480px;
    max-width:100%;
}

#backtolist {
    float: right;
    width: 80px;
    cursor: pointer;
}

#video_container {
    width: 100%;
    max-width: 480px;
    max-height: 270px;
}
